Page 78 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 78

Home

    instituted by artful and designing members [of
    Congress] .... I see, under a display of popular and
    fascinating guises, the most diabolical attempts to
    destroy ... the government." He further declared: "That
    they have been the fomenters of the western disturbance
    admits of no doubt." If "the daring and factious spirit"

    yor . oo

    is not crushed, "adieu to all government in this country,
    except mob and club government."

    When Genet was recalled as French envoy, he never
    returned to France, but went to live in New York where
    he carried on his revolutionary activities. He was

    1 a4 arn 1 1 ce

    replaced by M. Fauchet, another roving ambassador for
    the Illuminati.

    Fauchet to his superiors in France. Through these
    dispatches, Washington learned that a member of his
    own Cabinet, Edmund Randolph, was in league with
    French revolutionaries. This disclosure led to the

    resignation of Randolph.

    During the next five years a growing number of
    inflammatory journals calling for a French Revolution in
    America led to the Alien and Sedition Acts of 1798 as a

    A prominent individual to come out of one of the
    Illuminist lodges, the Columbian Lodge in New York,
    was Aaron Burr, the man who shot Alexander Hamilton.
    From 1801 to 1803 Aaron Burr actively organized

    73

    Attempts to Divide America

    Just how dangerous revolutionary activity was to the

    United States government became known with the

    accidental discovery of secret communications of M.

    means to deter threats of violence.